==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/SSM/DeletePatchBaseline.pm <==

package Paws::SSM::DeletePatchBaseline;
  use Moose;
  has BaselineId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeletePatchBaseline');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SSM::DeletePatchBaselineResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SSM::DeletePatchBaseline - Arguments for method DeletePatchBaseline on Paws::SSM

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeletePatchBaseline on the 
Amazon Simple Systems Manager (SSM) service. Use the attributes of this class
as arguments to method DeletePatchBaseline.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeletePatchBaseline.

As an example:

  $service_obj->DeletePatchBaseline(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> BaselineId => Str

The ID of the patch baseline to delete.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeletePatchBaseline in L<Paws::SSM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.45.tar.gz: Paws-0.45/lib/Paws/SSM/DeletePatchBaseline.pm <==

package Paws::SSM::DeletePatchBaseline;
  use Moose;
  has BaselineId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeletePatchBaseline');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SSM::DeletePatchBaselineResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SSM::DeletePatchBaseline - Arguments for method DeletePatchBaseline on L<Paws::SSM>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeletePatchBaseline on the
L<Amazon Simple Systems Manager (SSM)|Paws::SSM> service. Use the attributes of this class
as arguments to method DeletePatchBaseline.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeletePatchBaseline.

=head1 SYNOPSIS

    my $ssm = Paws->service('SSM');
    my $DeletePatchBaselineResult = $ssm->DeletePatchBaseline(
      BaselineId => 'MyBaselineId',

    );

    # Results:
    my $BaselineId = $DeletePatchBaselineResult->BaselineId;

    # Returns a L<Paws::SSM::DeletePatchBaselineResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ssm/DeletePatchBaseline>

=head1 ATTRIBUTES


=head2 B<REQUIRED> BaselineId => Str

The ID of the patch baseline to delete.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeletePatchBaseline in L<Paws::SSM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
